@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2023 Univention GmbH
+# Copyright 2017-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -155,6 +155,8 @@ def file_and_permission_checks() -> Iterator[CheckError]:
         cf_type('/var/mail/systemmail', 'systemmail', 'mail', 0o600, False),
         cf_type('/var/tmp/univention-management-console-frontend', 'root', 'root', 0o755, False),
         cf_type('/etc/freeradius/ssl', 'root', 'freerad', 0o2755, False),
+        cf_type('/usr/share/univention-management-console/oidc/oidc.json', 'root', 'root', 0o600, False),
+        cf_type('/etc/umc-oidc.secret', 'root', 'root', 0o600, False),
     ]
 
     iglob_paths = [
